The branch, master has been updated
       via  93339354a2342a8ed19216829a6c5743b5a2256f (commit)
      from  9d32b987e64cfcf539d1f88c87f84cfa37b477d8 (commit)


- Log -----------------------------------------------------------------
commit 93339354a2342a8ed19216829a6c5743b5a2256f
Author: Madhura Jayaratne <[email protected]>
Date:   Sat Mar 12 19:08:03 2011 +0530

    For geometry fields remove only the 'inline_edit' class.

-----------------------------------------------------------------------

Summary of changes:
 libraries/display_tbl.lib.php |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/libraries/display_tbl.lib.php b/libraries/display_tbl.lib.php
index ca8ef62..ef9e397 100644
--- a/libraries/display_tbl.lib.php
+++ b/libraries/display_tbl.lib.php
@@ -1365,9 +1365,9 @@ function PMA_displayTableBody(&$dt_result, &$is_display, 
$map, $analyzed_sql) {
             // g e o m e t r y
             } elseif ($meta->type == 'geometry') {
                 $geometry_text = PMA_handle_non_printable_contents('GEOMETRY', 
(isset($row[$i]) ? $row[$i] : ''), $transform_function, $transform_options, 
$default_function, $meta);
-                // reset $class from $inline_edit_class to 'data'
-                // as we can't edit geometry data
-                $class = 'data';
+
+                // remove 'inline_edit' from $class as we can't edit geometry 
data.
+                $class = str_replace('inline_edit', '', $class);
                 $vertical_display['data'][$row_no][$i]     =  
PMA_buildValueDisplay($class, $condition_field, $geometry_text);
                 unset($geometry_text);
 


hooks/post-receive
-- 
phpMyAdmin

------------------------------------------------------------------------------
Colocation vs. Managed Hosting
A question and answer guide to determining the best fit
for your organization - today and in the future.
http://p.sf.net/sfu/internap-sfd2d
_______________________________________________
Phpmyadmin-git mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/phpmyadmin-git

Reply via email to